Area - Github style

#####
coder commits

<div id="wrapper"> <div id="chart-months"> <apexchart type="area" height="160" :options="chartOptions" :series="series"></apexchart> </div> <h5 class="github-style"> <img class="userimg" src="https://picsum.photos/200/200/?image=1031" data-hovercard-user-id="634573" alt="" width="38" height="38" /> <div class="userdetails"> <a class="username">coder</a> <span class="cmeta"> <span class="commits"></span> commits </span> </div> </h5> <div id="chart-years"> <apexchart type="area" height="200" :options="chartOptionsYears" :series="seriesYears"></apexchart> </div> </div>